OiRA

Help

1. Příprava
2. Zapojení
3. Vyhledání rizik + Hodnocení rizik
   1. 1 Commercial manned guarding
   2. Ω Rizika přidaná uživatelem
      1. Ω.1 The entrance floor is often wet
   - Nezodpovězeno
   - Odloženo
   - OK
   - Pozornost
4. Akční plán
5. Zpráva
6. Status 0%

Pokud jste zjistili rizika, která nástroj neobsahuje, můžete je nyní přidat:

Důležité: Aby nedocházelo k duplikování rizik, důrazně doporučujeme, abyste si nejprve prošli všechny předchozí moduly, pokud jste tak ještě neučinili.

Pokud nepotřebujete přidávat rizika, pokračujte.

Předchozí Přejít do akčního plánu

Scroll to top
Back

## other-risks.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More